# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import jsonfield.fields


class Migration(migrations.Migration):

    dependencies = [
        ('dynsettings', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='JSONDynamicSetting',
            fields=[
                ('dynamicsetting_ptr', models.OneToOneField(parent_link=True, auto_created=True, on_delete=models.CASCADE, primary_key=True, serialize=False, to='dynsettings.DynamicSetting')),
                ('value', jsonfield.fields.JSONField(help_text='Setting value. It must be valid JSON. This setting type is intended only for developers and users who know how to compose valid JSON values. Do not edit them unless you know what are you doing. If, by other means / database access, you or someone corrupts the value of this field, enter by the same mean and restore its original value, or just {} (open and close curly bracers) to have a valid value.', verbose_name='Value')),
            ],
            options={
                'verbose_name': 'JSON Dynamic Setting',
                'verbose_name_plural': 'JSON Dynamic Settings',
            },
            bases=('dynsettings.dynamicsetting',),
        ),
        migrations.AlterModelOptions(
            name='booleandynamicsetting',
            options={'verbose_name': 'Boolean Dynamic Setting', 'verbose_name_plural': 'Boolean Dynamic Settings'},
        ),
        migrations.AlterModelOptions(
            name='decimaldynamicsetting',
            options={'verbose_name': 'Decimal Dynamic Setting', 'verbose_name_plural': 'Decimal Dynamic Settings'},
        ),
        migrations.AlterModelOptions(
            name='dynamicsetting',
            options={'verbose_name': 'Dynamic Setting', 'verbose_name_plural': 'Dynamic Settings'},
        ),
        migrations.AlterModelOptions(
            name='integerdynamicsetting',
            options={'verbose_name': 'Integer Dynamic Setting', 'verbose_name_plural': 'Integer Dynamic Settings'},
        ),
        migrations.AlterModelOptions(
            name='longtextdynamicsetting',
            options={'verbose_name': 'Long Text Dynamic Setting', 'verbose_name_plural': 'Long Text Dynamic Settings'},
        ),
        migrations.AlterModelOptions(
            name='shorttextdynamicsetting',
            options={'verbose_name': 'Short Text Dynamic Setting', 'verbose_name_plural': 'Short Text Dynamic Settings'},
        ),
    ]



from django.conf import settings as django_settings
from django.core.exceptions import ObjectDoesNotExist
from .models import DynamicSetting


class Settings(object):

    def __getattr__(self, item):
        try:
            return DynamicSetting.objects.get(name=item).value
        except ObjectDoesNotExist:
            return getattr(django_settings, item)


settings = Settings()


# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import django.core.validators


class Migration(migrations.Migration):

    dependencies = [
        ('contenttypes', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='DynamicSetting',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('name', models.CharField(help_text='Setting name. Since it will be accessed from python code, the syntax is the same as for any valid python identifier', max_length=255, verbose_name='Name', validators=[django.core.validators.RegexValidator(b'^[a-zA-Z_][a-zA-Z0-9_]+', 'Setting name must consist in a-z letters, numbers, and underscores, and cannot start with a number')])),
                ('allow_null', models.BooleanField(default=False, help_text='Check this to allow null value in this setting.', verbose_name='Allow null value')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='BooleanDynamicSetting',
            fields=[
                ('dynamicsetting_ptr', models.OneToOneField(parent_link=True, auto_created=True, on_delete=models.CASCADE, primary_key=True, serialize=False, to='dynsettings.DynamicSetting')),
                ('value', models.NullBooleanField(help_text='Setting value. It must be marked, not marked, or undefined.', verbose_name='Value')),
            ],
            options={
                'abstract': False,
            },
            bases=('dynsettings.dynamicsetting',),
        ),
        migrations.CreateModel(
            name='DecimalDynamicSetting',
            fields=[
                ('dynamicsetting_ptr', models.OneToOneField(parent_link=True, auto_created=True, on_delete=models.CASCADE, primary_key=True, serialize=False, to='dynsettings.DynamicSetting')),
                ('value', models.DecimalField(decimal_places=16, max_digits=32, blank=True, help_text='Setting value. It must be a valid numeric value.', null=True, verbose_name='Value')),
            ],
            options={
                'abstract': False,
            },
            bases=('dynsettings.dynamicsetting',),
        ),
        migrations.CreateModel(
            name='IntegerDynamicSetting',
            fields=[
                ('dynamicsetting_ptr', models.OneToOneField(parent_link=True, auto_created=True, on_delete=models.CASCADE, primary_key=True, serialize=False, to='dynsettings.DynamicSetting')),
                ('value', models.IntegerField(help_text='Setting value. It must be a valid (signed, 4-byte) integer value.', null=True, verbose_name='Value', blank=True)),
            ],
            options={
                'abstract': False,
            },
            bases=('dynsettings.dynamicsetting',),
        ),
        migrations.CreateModel(
            name='LongTextDynamicSetting',
            fields=[
                ('dynamicsetting_ptr', models.OneToOneField(parent_link=True, auto_created=True, on_delete=models.CASCADE, primary_key=True, serialize=False, to='dynsettings.DynamicSetting')),
                ('value', models.TextField(help_text='Setting value.', max_length=16777215, null=True, blank=True, verbose_name='Value')),
            ],
            options={
                'abstract': False,
            },
            bases=('dynsettings.dynamicsetting',),
        ),
        migrations.CreateModel(
            name='ShortTextDynamicSetting',
            fields=[
                ('dynamicsetting_ptr', models.OneToOneField(parent_link=True, auto_created=True, on_delete=models.CASCADE, primary_key=True, serialize=False, to='dynsettings.DynamicSetting')),
                ('value', models.CharField(help_text='Setting value.', max_length=255, null=True, verbose_name='Value', blank=True)),
            ],
            options={
                'abstract': False,
            },
            bases=('dynsettings.dynamicsetting',),
        ),
        migrations.AddField(
            model_name='dynamicsetting',
            name='polymorphic_ctype',
            field=models.ForeignKey(related_name='polymorphic_dynsettings.dynamicsetting_set+', editable=False, to='contenttypes.ContentType', null=True, on_delete=models.PROTECT),
        ),
    ]



from setuptools import setup

setup(
    name='django-dynsettings-ritual',
    version='0.0.9',
    packages=[
        'grimoire.django.dynsettings',
        'grimoire.django.dynsettings.migrations',
    ],
    package_data={
        'grimoire.django.dynsettings': [
            'locale/*/LC_MESSAGES/*.*'
        ]
    },
    url='https://github.com/luismasuelli/django-dynsettings-ritual',
    license='LGPL',
    author='Luis y Anita',
    author_email='luismasuelli@hotmail.com',
    description='A Django application used to store dynamic settings (i.e. settings beyond the settings.py file), '
                'and retrieve them via another special object (instead of django.conf.settings, and wrapping it).',
    install_requires=['django-trackmodels-ritual>=1.0.0', 'jsonfield>=3.0.0',
                      'django-polymorphic>=2.1.2']
)